/********************************************************************
*==================  		ЗАО "ННН"		========================*
*********************************************************************/
/*!
* \file				ystddelegate.cpp
* \brief			Реализация класса YStdDelegate
* \framework{		Qt 4.3.4}
* \compiller{		GCC (MinGW32-gcc rev3.4.5)}
* \date				6.04.2008	8.04.2008
* \author			Литкевич Юрий Иванович
*/
/*
* Support E-mail:	lit-uriy@yandex.ru
* Лицензия:			GNU GPLv2
* TabSize:			4
* Encodding:		UTF-8 (w/o BOM)	
*						 
* 							
* 		 					
* 							
* Log:
* Date				Athor				Description
* 
*
********************************************************************/



#include <QtGui>

#include "ystddelegate.h"

/*!
 *	\brief	Конструктор класса
 *
 *	Создает делегат с заданным типом виджета-редактора
 */
YStdDelegate::YStdDelegate(TypeEditor type, QObject *parent)
    : QItemDelegate(parent)
{
	typeeditor = type;
}


/*!
 *	\brief	Функция создания виджета-редактора
 */
QWidget *YStdDelegate::createEditor(QWidget *parent,const QStyleOptionViewItem &,
									const QModelIndex &) const
{
  QWidget *editor;

	switch(typeeditor)
	{
		case TBool:
			QComboBox *cmbox = new QComboBox(parent);
			cmbox->addItem("0");
			cmbox->addItem("1");
			return static_cast<QWidget *>(cmbox);
		case TQDateTimeEdit:
			editor = static_cast<QDateTimeEdit *>(new QDateTimeEdit(parent));
			break;
		default:
			editor = static_cast<QSpinBox *>(new QSpinBox(parent));
	}
	return editor;
}

/*!
 *	\brief	Функция заполнения виджета-редактора данными из модели
 */
void YStdDelegate::setEditorData(QWidget *editor,
                                    const QModelIndex &index) const
{
    QVariant data = index.model()->data(index, Qt::DisplayRole);
	
	switch(typeeditor)
	{
		case TBool:
			QComboBox *cmbox = static_cast<QComboBox *>(editor);
			if (data.toInt())
			{
				cmbox->setCurrentIndex(cmbox->findText("1"));
			}   
			else
			{
				cmbox->setCurrentIndex(cmbox->findText("0"));			
			}
			break;
		case TQDateTimeEdit:
			QDateTimeEdit *dtedit = static_cast<QDateTimeEdit *>(editor);
			
			dtedit->setDateTime(data.toDateTime());
			break;
		default:
			QSpinBox *spinBox = static_cast<QSpinBox *>(editor);
			spinBox->setValue(data.toInt());
	}
    
   
}

/*!
 *	\brief	Функция заполнения модели данными из виджета-редактора
 */
void YStdDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
                                   const QModelIndex &index) const
{
  QVariant data;

	switch(typeeditor)
	{
		case TBool:
			QComboBox *cmbox = static_cast<QComboBox *>(editor);
			data = cmbox->currentText();
			break;
		case TQDateTimeEdit:
			QDateTimeEdit *dtedit = static_cast<QDateTimeEdit *>(editor);
			data = dtedit->dateTime();
			break;
		default:
			QSpinBox *spinBox = static_cast<QSpinBox *>(editor);
			spinBox->interpretText();
			data = spinBox->value();
	}


    model->setData(index, data, Qt::EditRole);
}

void YStdDelegate::updateEditorGeometry(QWidget *editor,
    const QStyleOptionViewItem &option, const QModelIndex &/* index */) const
{
    editor->setGeometry(option.rect);
}
